==> ModuleXtender-0.2.1.zip: ModuleXtender-0.2.1/method.upgrade.php <==
<?php
if (!isset($gCms)) exit;

	/*---------------------------------------------------------
	   Upgrade()
	   If your module version number does not match the version
	   number of the installed module, the CMS Admin will give
	   you a chance to upgrade the module. This is the function
	   that actually handles the upgrade.
	   Ideally, this function should handle upgrades incrementally,
	   so you could upgrade from version 0.0.1 to 10.5.7 with
	   a single call. For a great example of this, see the News
	   module in the standard CMS install.
	  ---------------------------------------------------------*/
		$current_version = $oldversion;
		
				$dict = NewDataDictionary($db);
		
		switch($current_version)
		{
			case "0.0.2":
				$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_documents", "type C(255)");
				$dict->ExecuteSQLArray($sqlarray);				
			     $current_version = "0.0.2.1";
			     
			case "0.0.2.1":

				$this->SetPreference('fe.general','fe.general');
				$this->SetPreference('fe.documents','fe.documents');
				$this->SetPreference('fe.images','fe.images');
				
				$this->SetTemplate('fe.documents', $this->GetTemplateFromFile('fe.documents'));
				$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
				$this->SetTemplate('fe.general', $this->GetTemplateFromFile('fe.general'));
				$current_version = "0.0.2.3";
				
			case "0.0.2.3":
				
				$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_xtendedmodules", "options C(255)");
				$dict->ExecuteSQLArray($sqlarray);
				
				$current_version = "0.0.2.4";	
				
		   case "0.0.2.4":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.5":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.6":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.7":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.8":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.9":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.3.0":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.1":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.2":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.3":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.4":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.5":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.6":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.7":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.8":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.4.0":
			    
			    $current_version = "0.0.4.3";
			  case "0.0.4.1":
			    
			    $current_version = "0.0.4.3";
			  case "0.0.4.2":
			    
			    $current_version = "0.0.4.3";

		   case "0.0.4.3":

				$this->SetPreference('fe.categories','fe.categories');
				$this->SetPreference('fe.pages','fe.pages');

				$this->SetTemplate('fe.categories', $this->GetTemplateFromFile('fe.categories'));
				$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
				
				 // StyleSheet
        
                $stylesheet = new stdClass();
    			$stylesheet->name = $this->GetName() . '.css';
    			$stylesheet->value = $this->GetTemplateFromFile('style.css');
    			$stylesoperations = $gCms->GetStylesheetOperations();		
    			$stylesoperations->InsertStylesheet($stylesheet);

				$current_version = "0.0.4.4";	
				
		   case '0.0.4.4':
		   	  $current_version = '0.0.5.1';

		   
       case '0.0.4.5':
          $current_version = '0.0.5.1';

          
          
       case '0.0.4.6':
          $current_version = '0.0.5.1';

					
          
       case '0.0.4.7':
          $current_version = '0.0.5.1';

          
       case '0.0.4.8':
          $current_version = '0.0.5.1';

          
       case '0.0.4.9':
          $current_version = '0.0.5.1';

          
       case '0.0.4.10':
          $current_version = '0.0.5.1';

          
       case '0.0.4.11':
          $current_version = '0.0.5.1';

          
       case '0.0.5.0':
          $current_version = '0.0.5.1';

       case '0.0.5.1':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "title C(255)");
          $dict->ExecuteSQLArray($sqlarray);
        
          $current_version = '0.0.5.2';

       case '0.0.5.2':
       	  $current_version = '0.0.6';

       case '0.0.5.3':
       	  $current_version = '0.0.6';
       	  
       case '0.0.5.3.1':
          $current_version = '0.0.8';
       case '0.0.6':
       	$current_version = '0.0.8';
       case '0.0.7':
       	$current_version = '0.0.8';
       case '0.0.8':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "position I");
          $dict->ExecuteSQLArray($sqlarray);
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_categories", "position I");     	  
          $dict->ExecuteSQLArray($sqlarray);
          MX_Document::resetAllPositions();
          MX_Option::resetAllPositions();          
       	  $current_version = '0.1.0';
       case '0.1.0':
       	$current_version = '0.1.2';
       case '0.1.1':
       	$current_version = '0.1.2';
       case '0.1.2':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_filter I");
          $dict->ExecuteSQLArray($sqlarray);
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_sortable I");
          $dict->ExecuteSQLArray($sqlarray);
          MX_Relation::resetAllPositions();
          MX_Option::resetAllPositions();  
          $current_version = '0.1.4';
       case '0.1.3':
       	$current_version = '0.1.4';
       case '0.1.4':
       	$current_version = '0.1.9';
       case '0.1.5':
       	$current_version = '0.1.9';
       case '0.1.6':
       	$current_version = '0.1.9';
       case '0.1.7':
       	$current_version = '0.1.9';
       case '0.1.8':
       	$current_version = '0.1.9';
       case '0.1.9':
        $current_version = '0.1.10';
       case '0.1.10':
          $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "have_column I");
          $dict->ExecuteSQLArray($sqlarray);
          $current_version = '0.1.11';
       case '0.1.11':
       	$current_version = '0.1.12';
       case '0.1.12':
       	$current_version = '0.1.14';
       case '0.1.14':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_unique I");
          $dict->ExecuteSQLArray($sqlarray);
		      $flds = "
		      id I KEY,
		      modulename C(255),
		      module_id I,
		      title C(255),     
		      url XL,
		      is_new_window I,
		      position I
		      ";		
		    // create it.
		    $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_links",
		        $flds, $taboptarray);
		    $dict->ExecuteSQLArray($sqlarray);
		
		    // create a sequence
		    $db->CreateSequence(cms_db_prefix()."module_modulextender_links_seq");  
          
       	$current_version = '0.1.17';
       case '0.1.15':
        $current_version = '0.1.17';	
       case '0.1.16':
        $current_version = '0.1.17';	
       case '0.1.17':
       	    // TABLE Associated category
				    //################
				        
				    // table schema description
				        $flds = "
				      id I KEY,
				      type C(255),
				      modulename C(255),
				      category_id I,
				      position I
				      ";
				
				    // create it.
				    $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_related_categories",
				        $flds, $taboptarray);
				    $dict->ExecuteSQLArray($sqlarray);
				
				    // create a sequence
				    $db->CreateSequence(cms_db_prefix()."module_modulextender_related_categories_seq"); 
				    $current_version = '0.2.0';
				
       case '0.1.18':
        $current_version = '0.2.0';      
       case '0.1.19':
        $current_version = '0.2.0';      
       case '0.1.20':
        $current_version = '0.2.0';      
       case '0.1.21':
        $current_version = '0.2.0';      
       case '0.1.22':
        $current_version = '0.2.0'; 
             
       case '0.2.0':
       	 $this->setPreference('images_size', array( 
				      'thumbnails' => array('width'=>100  , 'height'=>100) 
				    , 'thumbnail' => array('width'=>100  , 'height'=>100) 
				    , 'low' => array('width'=>170  , 'height'=>170) 
				    , 'home' => array( 'width'=>187, 'height'=>187)
				    , 'medium' => array( 'width'=>208, 'height'=>208)
				    , 'high' => array('width'=>600, 'height'=>600)
				    , 'cover' => array('width'=>57, 'height'=>80)    
				    )
				    );
				    
		}
		
		// put mention into the admin log
		$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

?>

==> ModuleXtender-0.2.3.zip: ModuleXtender-0.2.3/method.upgrade.php <==
<?php
if (!isset($gCms)) exit;

	/*---------------------------------------------------------
	   Upgrade()
	   If your module version number does not match the version
	   number of the installed module, the CMS Admin will give
	   you a chance to upgrade the module. This is the function
	   that actually handles the upgrade.
	   Ideally, this function should handle upgrades incrementally,
	   so you could upgrade from version 0.0.1 to 10.5.7 with
	   a single call. For a great example of this, see the News
	   module in the standard CMS install.
	  ---------------------------------------------------------*/
		$current_version = $oldversion;
		
				$dict = NewDataDictionary($db);
		
		switch($current_version)
		{
			case "0.0.2":
				$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_documents", "type C(255)");
				$dict->ExecuteSQLArray($sqlarray);				
			     $current_version = "0.0.2.1";
			     
			case "0.0.2.1":

				$this->SetPreference('fe.general','fe.general');
				$this->SetPreference('fe.documents','fe.documents');
				$this->SetPreference('fe.images','fe.images');
				
				$this->SetTemplate('fe.documents', $this->GetTemplateFromFile('fe.documents'));
				$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
				$this->SetTemplate('fe.general', $this->GetTemplateFromFile('fe.general'));
				$current_version = "0.0.2.3";
				
			case "0.0.2.3":
				
				$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_xtendedmodules", "options C(255)");
				$dict->ExecuteSQLArray($sqlarray);
				
				$current_version = "0.0.2.4";	
				
		   case "0.0.2.4":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.5":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.6":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.7":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.8":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.2.9":
			    
			    $current_version = "0.0.4.3";
			    
			case "0.0.3.0":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.1":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.2":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.3":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.4":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.5":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.6":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.7":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.3.8":
			    
			    $current_version = "0.0.4.3";
			 case "0.0.4.0":
			    
			    $current_version = "0.0.4.3";
			  case "0.0.4.1":
			    
			    $current_version = "0.0.4.3";
			  case "0.0.4.2":
			    
			    $current_version = "0.0.4.3";

		   case "0.0.4.3":

				$this->SetPreference('fe.categories','fe.categories');
				$this->SetPreference('fe.pages','fe.pages');

				$this->SetTemplate('fe.categories', $this->GetTemplateFromFile('fe.categories'));
				$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
			
				$current_version = "0.0.4.4";	
				
		   case '0.0.4.4':
		   	  $current_version = '0.0.5.1';

		   
       case '0.0.4.5':
          $current_version = '0.0.5.1';

          
          
       case '0.0.4.6':
          $current_version = '0.0.5.1';

					
          
       case '0.0.4.7':
          $current_version = '0.0.5.1';

          
       case '0.0.4.8':
          $current_version = '0.0.5.1';

          
       case '0.0.4.9':
          $current_version = '0.0.5.1';

          
       case '0.0.4.10':
          $current_version = '0.0.5.1';

          
       case '0.0.4.11':
          $current_version = '0.0.5.1';

          
       case '0.0.5.0':
          $current_version = '0.0.5.1';

       case '0.0.5.1':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "title C(255)");
          $dict->ExecuteSQLArray($sqlarray);
        
          $current_version = '0.0.5.2';

       case '0.0.5.2':
       	  $current_version = '0.0.6';

       case '0.0.5.3':
       	  $current_version = '0.0.6';
       	  
       case '0.0.5.3.1':
          $current_version = '0.0.8';
       case '0.0.6':
       	$current_version = '0.0.8';
       case '0.0.7':
       	$current_version = '0.0.8';
       case '0.0.8':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "position I");
          $dict->ExecuteSQLArray($sqlarray);
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_categories", "position I");     	  
          $dict->ExecuteSQLArray($sqlarray);
          MX_Document::resetAllPositions();
          MX_Option::resetAllPositions();          
       	  $current_version = '0.1.0';
       case '0.1.0':
       	$current_version = '0.1.2';
       case '0.1.1':
       	$current_version = '0.1.2';
       case '0.1.2':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_filter I");
          $dict->ExecuteSQLArray($sqlarray);
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_sortable I");
          $dict->ExecuteSQLArray($sqlarray);
          MX_Relation::resetAllPositions();
          MX_Option::resetAllPositions();  
          $current_version = '0.1.4';
       case '0.1.3':
       	$current_version = '0.1.4';
       case '0.1.4':
       	$current_version = '0.1.9';
       case '0.1.5':
       	$current_version = '0.1.9';
       case '0.1.6':
       	$current_version = '0.1.9';
       case '0.1.7':
       	$current_version = '0.1.9';
       case '0.1.8':
       	$current_version = '0.1.9';
       case '0.1.9':
        $current_version = '0.1.10';
       case '0.1.10':
          $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "have_column I");
          $dict->ExecuteSQLArray($sqlarray);
          $current_version = '0.1.11';
       case '0.1.11':
       	$current_version = '0.1.12';
       case '0.1.12':
       	$current_version = '0.1.14';
       case '0.1.14':
       	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_modulextender_relations", "is_unique I");
          $dict->ExecuteSQLArray($sqlarray);
		      $flds = "
		      id I KEY,
		      modulename C(255),
		      module_id I,
		      title C(255),     
		      url XL,
		      is_new_window I,
		      position I
		      ";		
		    // create it.
		    $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_links",
		        $flds, $taboptarray);
		    $dict->ExecuteSQLArray($sqlarray);
		
		    // create a sequence
		    $db->CreateSequence(cms_db_prefix()."module_modulextender_links_seq");  
          
       	$current_version = '0.1.17';
       case '0.1.15':
        $current_version = '0.1.17';	
       case '0.1.16':
        $current_version = '0.1.17';	
       case '0.1.17':
       	    // TABLE Associated category
				    //################
				        
				    // table schema description
				        $flds = "
				      id I KEY,
				      type C(255),
				      modulename C(255),
				      category_id I,
				      position I
				      ";
				
				    // create it.
				    $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_related_categories",
				        $flds, $taboptarray);
				    $dict->ExecuteSQLArray($sqlarray);
				
				    // create a sequence
				    $db->CreateSequence(cms_db_prefix()."module_modulextender_related_categories_seq"); 
				    $current_version = '0.2.0';
				
       case '0.1.18':
        $current_version = '0.2.0';      
       case '0.1.19':
        $current_version = '0.2.0';      
       case '0.1.20':
        $current_version = '0.2.0';      
       case '0.1.21':
        $current_version = '0.2.0';      
       case '0.1.22':
        $current_version = '0.2.0'; 
             
       case '0.2.0':
				$this->setPreference('images_size', serialize(array( 
				        'thumbnails' => array('width'=>100  , 'height'=>100) 
				      , 'thumbnail' => array('width'=>100  , 'height'=>100) 
				      , 'low' => array('width'=>170  , 'height'=>170) 
				      , 'home' => array( 'width'=>187, 'height'=>187)
				      , 'medium' => array( 'width'=>208, 'height'=>208)
				      , 'high' => array('width'=>600, 'height'=>600)
				      , 'cover' => array('width'=>57, 'height'=>80)    
				      ))
				      );
				$current_version = '0.2.3';
      case '0.2.1':
        $current_version= '0.2.3';
      case '0.2.2':
        $current_version= '0.2.3';
      case '0.2.3':
        $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_modulextender_relations_link", "rel_id C(255)");
        $dict->ExecuteSQLArray($sqlarray);
        $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_modulextender_relations", "rel_id C(255)");
        $dict->ExecuteSQLArray($sqlarray); 
				//$current_version= '0.2.3';
        				    
		}
		
		// put mention into the admin log
		$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

?>
